@@ -68,7 +68,7 @@ class Queue(OrchestratorHTTP):
         data = self._get(url)
         return data
 
-    def start(self, machine_identifier, specific_content=None, references=None, separator="-", fields=None):
+    def start(self, machine_identifier, specific_content=None, batch_id=None, references=None, separator="-", fields=None):
         """
             Starts a given transaction
 
@@ -78,7 +78,7 @@ class Queue(OrchestratorHTTP):
             :param fields: a dictionary of additional fields to be added/modify to the specific content
         """
         ran_uuid = str(uuid4())
-        batch_id = str(uuid.uuid4())
+        #batch_id = str(uuid.uuid4())
         logging.debug("Starting new transaction")
         endpoint = "/Queues/UiPathODataSvc.StartTransaction"
         format_body_start = {
